==> deepin-compressor-debug-6.5.2-1-x86_64.pkg.tar.zst: usr/src/debug/deepin-compressor/deepin-compressor/src/qrc_config.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 6.10.0
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#ifdef _MSC_VER
// disable informational message "function ... selected for automatic inline expansion"
#pragma warning (disable: 4711)
#endif

static const unsigned char qt_resource_data[] = {
  // deepin-compressor.json
  0x0,0x0,0x3,0x3e,
  0x28,
  0xb5,0x2f,0xfd,0x60,0xee,0x2a,0xa5,0x19,0x0,0xa6,0xda,0x4e,0x1f,0x30,0x73,0x1e,
  0x58,0x76,0x74,0xd3,0xcc,0xd,0xd7,0x23,0x9b,0xc7,0xb6,0xdc,0x6a,0x72,0x6a,0x28,
  0x2b,0xd9,0xdf,0xdf,0xf7,0x80,0x8c,0xc2,0x40,0x1,0xe5,0x4,0x46,0x0,0x45,0x0,
  0x46,0x0,0xfd,0x16,0xe3,0xe2,0xd7,0x38,0xc6,0x38,0xe6,0x4c,0xc1,0xbe,0x48,0xfc,
  0xcb,0xee,0x4,0x1f,0xe8,0xea,0x69,0x76,0x5e,0x0,0x61,0x7e,0xa7,0xf4,0xd0,0xda,
  0xcb,0x6c,0xd9,0xef,0xdd,0xfa,0x5f,0xe,0x4a,0xd9,0x67,0x6c,0xc7,0x14,0x5c,0x67,
  0xc9,0x10,0x8e,0x2b,0x5,0x10,0xd3,0x9d,0xa0,0xe,0x6b,0x20,0x6,0xa8,0xb0,0x5,
  0x44,0xa7,0xd5,0x5e,0x41,0xc,0xe0,0x9,0x81,0x9a,0x68,0x51,0x4d,0x44,0xd7,0x44,
  0xa2,0x98,0xc1,0xe8,0x3e,0xd7,0x94,0xae,0xec,0xc7,0x9c,0xff,0xb2,0xd,0x89,0x62,
  0x29,0xc2,0x18,0xbe,0xc7,0x4b,0x8e,0x5c,0xad,0xdc,0x28,0x1,0x2c,0x14,0xee,0x85,
  0xe2,0x67,0xc8,0x24,0x63,0x38,0x8c,0xd3,0x18,0x89,0xe4,0xd9,0x6c,0xf9,0x53,0x86,
  0xef,0xc2,0x28,0x66,0xc6,0x70,0xbe,0x87,0x56,0x64,0xce,0x96,0xb1,0x3,0xdf,0x6f,
  0xdf,0x9c,0x3b,0x6f,0x87,0xd,0x8d,0xd3,0x5b,0x9c,0xee,0xcd,0xd7,0xa7,0x75,0x6d,
  0x5a,0x17,0xd1,0xd8,0x36,0x56,0xe8,0x9b,0x69,0xbb,0xd9,0x4c,0xd5,0xaa,0x89,0xa9,
  0xc6,0xd5,0x6a,0xdc,0xce,0xa8,0xe3,0x2b,0xdf,0x34,0x90,0xfb,0x26,0xa6,0x6,0x94,
  0xdc,0x54,0x83,0x42,0x9d,0xda,0x7c,0xb5,0xf5,0x9b,0x6e,0xda,0xb6,0x79,0x18,0xe7,
  0x1b,0x5d,0x1,0x80,0xf,0x0,0x32,0x14,0xa,0xb2,0xff,0xad,0x29,0x8a,0xfd,0xd4,
  0x92,0xb0,0x97,0xfd,0x80,0x9d,0xa7,0x97,0xbb,0x26,0xfb,0x51,0xc9,0x7f,0x71,0xc4,
  0xb1,0x1d,0xe3,0x6,0xce,0x69,0x63,0xe7,0x56,0xd3,0x36,0xe7,0x36,0x7d,0x2d,0xbe,
  0x88,0x80,0x40,0x28,0x9a,0xbe,0xe6,0x7b,0x35,0x5f,0x4a,0xad,0xf5,0xaa,0x57,0xd7,
  0xae,0x1b,0x37,0x6e,0x84,0x10,0x6,0x80,0xb7,0xa8,0xe1,0x21,0x63,0x37,0x93,0x82,
  0x24,0xcb,0x1c,0x30,0x84,0x10,0x32,0x72,0xd0,0xa6,0x3,0x52,0x50,0x28,0x46,0x31,
  0x4,0x8,0x49,0x10,0x11,0x20,0x8,0x46,0x80,0x90,0x8,0x82,0x20,0x4,0xc,0x41,
  0x83,0x10,0xa1,0x11,0x18,0x24,0x20,0x2,0x22,0x40,0xd4,0xf,0x33,0xb7,0x5d,0x14,
  0xf9,0x92,0x14,0xb3,0xd,0x5e,0x4c,0xda,0xb9,0x6a,0x4a,0x62,0x52,0x43,0xd,0xb6,
  0xc5,0xbf,0xec,0x99,0x43,0x2d,0x4,0x45,0x3,0x44,0x2c,0x6,0x77,0x62,0x10,0x3a,
  0x39,0x1,0x9,0x2d,0xb2,0xa,0x19,0x3c,0xe4,0xa5,0xc6,0x44,0x80,0xeb,0xe3,0x4d,
  0x16,0xc1,0x15,0x97,0xd4,0x31,0x60,0x4a,0xaa,0x8,0xa6,0xa1,0xe0,0x6b,0x46,0xa,
  0xb7,0xc9,0x0,0x49,0x22,0x61,0xa5,0xf,0x48,0xbe,0x6,0x54,0xd8,0x68,0x31,0x85,
  0x1d,0x3b,0xeb,0xcb,0x6c,0xa1,0x5,0x71,0xa2,0x7,0x83,0x0,0x99,0x2e,0x0,0x49,
  0x2,0x40,0xe2,0x14,0xc6,0x8,0x69,0xe1,0x73,0xa0,0x42,0x49,0xe0,0xe8,0x15,0x7e,
  0x9b,0x5d,0xcd,0x70,0xe8,0x1c,0xad,0x88,0xf7,0xe2,0xce,0x39,0x33,0x2,0x2b,0x90,
  0x65,0x6c,0x11,0xe3,0xd9,0xab,0x9,0xab,0x7f,0x3d,0x18,0x82,0x84,0x89,0x15,0x3d,
  0xc1,0x64,0x61,0x9c,0x1c,0x92,0x91,0x36,0x4c,0x0,0x6c,0x69,0x25,0x62,0xe3,0x4f,
  0xdc,0xe7,0x3b,0x90,0x15,0x72,0x33,0x2c,0xe4,0xe8,0x96,0x83,0x14,0x1c,0x99,0xfe,
  0x26,0xaa,0x6b,0x29,0x3a,0x21,0x6,0xd0,0x2b,0xcc,0xfd,0x25,0x0,0xa2,0xa5,0x53,
  0x89,0x30,0x2,0x1,0xec,0x95,0xe8,0x3f,0x89,0xe8,0xca,0x57,0xa5,0x6f,0x18,0xaa,
  0x70,0x47,0xb,0xe2,0x3f,0x47,0x1d,0x50,0x43,0xd1,0xa0,0x2b,0x6d,0x21,0xb4,0x90,
  0xa4,0x83,0xd1,0xa1,0xe,0x41,0x7,0x19,0xd1,0x81,0x55,0xc8,0xfd,0x41,0x7e,0x22,
  0x84,0x89,0x43,0xb0,0x70,0x97,0xfe,0x40,0x46,0x84,0x94,0x35,0x2c,0xb6,0x87,0x56,
  0x2b,0x80,0xd9,0x74,0x52,0xbb,0xf9,0xf8,0x31,0x86,0x66,0xf6,0xa2,0x1,0x66,0x22,
  0xbd,0x14,0x44,0x25,0xee,0x4,0x61,0x0,0x33,0x53,0x47,0x16,0xed,0xa5,0xc1,0x3a,
  0x5a,0x46,0xc,0xf4,0x8c,0x70,0x97,0xf,0xd1,0x7,0xc9,0x4b,0x96,0xbd,0x4b,0x98,
  0xa0,0x19,0x84,0xcb,0xa7,0x87,0xdf,0x3,0x93,0x2b,0x8a,0xa1,0x1f,0xf0,0x1,0x4,
  0x5,0x70,0xad,0xde,0x5d,0x5b,0x92,0x96,0x0,0x2d,0x91,0xf1,0xfb,0xd1,0x86,0xac,
  0x24,0xd9,0x97,0xc4,0xf9,0x15,0xff,0x85,0xa8,0x32,0xb6,0xc0,0x3b,0x9e,0xb0,0xce,
  0x71,0x8a,0xaa,0xd8,0x2b,0xe3,0x14,0x78,0xf4,0x94,0x1a,0xa2,0x48,0x26,0x13,0xf8,
  0xd8,0x44,0x48,0x8c,0xce,0x59,0xc6,0x63,0x17,0x7e,0xde,0x16,0xef,0x7e,0x55,0xd6,
  0x4,0x60,0xf1,0xf8,0x24,0x6e,0x47,0x2d,0xa0,0x1a,0x3c,0xf,0x75,0x93,0x2a,0x5e,
  0xdf,0xa3,0x1d,0x1e,0x1b,0xcb,0xdc,0x1b,0xe1,0x4f,0x48,0x71,0x88,0x22,0xd3,0x42,
  0xb3,0xc7,0x56,0xb0,0x70,0xdc,0x17,0xab,0x13,0x93,0xf,0xef,0x45,0xe7,0xf8,0x33,
  0x42,0x3e,0x4,0x85,0xe,0x90,0xf7,0x4c,0xed,0xc2,0x4f,0xef,0x18,
  
};

static const unsigned char qt_resource_name[] = {
  // assets
  0x0,0x6,
  0x6,0x8a,0x9c,0xb3,
  0x0,0x61,
  0x0,0x73,0x0,0x73,0x0,0x65,0x0,0x74,0x0,0x73,
    // data
  0x0,0x4,
  0x0,0x6,0xa8,0xa1,
  0x0,0x64,
  0x0,0x61,0x0,0x74,0x0,0x61,
    // deepin-compressor.json
  0x0,0x16,
  0x2,0x95,0x4c,0xbe,
  0x0,0x64,
  0x0,0x65,0x0,0x65,0x0,0x70,0x0,0x69,0x0,0x6e,0x0,0x2d,0x0,0x63,0x0,0x6f,0x0,0x6d,0x0,0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,0x73,0x0,0x6f,0x0,0x72,
  0x0,0x2e,0x0,0x6a,0x0,0x73,0x0,0x6f,0x0,0x6e,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x99,0xe8,0xdd,0x91,0xf8,
  // :/assets
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x99,0xe8,0xdd,0x91,0xf8,
  // :/assets/data
  0x0,0x0,0x0,0x12,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x1,0x99,0xe8,0xdd,0x91,0xf8,
  // :/assets/data/deepin-compressor.json
  0x0,0x0,0x0,0x20,0x0,0x4,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x99,0xe8,0xdd,0x91,0xf8,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#if defined(QT_INLINE_NAMESPACE)
inline namespace QT_NAMESPACE {
#elif defined(QT_NAMESPACE)
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#if defined(__ELF__) || defined(__APPLE__)
static inline unsigned char qResourceFeatureZstd()
{
    extern const unsigned char qt_resourceFeatureZstd;
    return qt_resourceFeatureZstd;
}
#else
unsigned char qResourceFeatureZstd();
#endif

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_config)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_config)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_config)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_config)()
{
    int version = 3;
    version += QT_RCC_PREPEND_NAMESPACE(qResourceFeatureZstd());
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

#ifdef __clang__
#   pragma clang diagnostic push
#   pragma clang diagnostic ignored "-Wexit-time-destructors"
#endif

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_config)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_config)(); }
   } dummy;
}

#ifdef __clang__
#   pragma clang diagnostic pop
#endif

==> deepin-compressor-debug-6.5.3-1-x86_64.pkg.tar.zst: usr/src/debug/deepin-compressor/deepin-compressor/src/qrc_config.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 6.10.0
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#ifdef _MSC_VER
// disable informational message "function ... selected for automatic inline expansion"
#pragma warning (disable: 4711)
#endif

static const unsigned char qt_resource_data[] = {
  // deepin-compressor.json
  0x0,0x0,0x3,0x3e,
  0x28,
  0xb5,0x2f,0xfd,0x60,0xee,0x2a,0xa5,0x19,0x0,0xa6,0xda,0x4e,0x1f,0x30,0x73,0x1e,
  0x58,0x76,0x74,0xd3,0xcc,0xd,0xd7,0x23,0x9b,0xc7,0xb6,0xdc,0x6a,0x72,0x6a,0x28,
  0x2b,0xd9,0xdf,0xdf,0xf7,0x80,0x8c,0xc2,0x40,0x1,0xe5,0x4,0x46,0x0,0x45,0x0,
  0x46,0x0,0xfd,0x16,0xe3,0xe2,0xd7,0x38,0xc6,0x38,0xe6,0x4c,0xc1,0xbe,0x48,0xfc,
  0xcb,0xee,0x4,0x1f,0xe8,0xea,0x69,0x76,0x5e,0x0,0x61,0x7e,0xa7,0xf4,0xd0,0xda,
  0xcb,0x6c,0xd9,0xef,0xdd,0xfa,0x5f,0xe,0x4a,0xd9,0x67,0x6c,0xc7,0x14,0x5c,0x67,
  0xc9,0x10,0x8e,0x2b,0x5,0x10,0xd3,0x9d,0xa0,0xe,0x6b,0x20,0x6,0xa8,0xb0,0x5,
  0x44,0xa7,0xd5,0x5e,0x41,0xc,0xe0,0x9,0x81,0x9a,0x68,0x51,0x4d,0x44,0xd7,0x44,
  0xa2,0x98,0xc1,0xe8,0x3e,0xd7,0x94,0xae,0xec,0xc7,0x9c,0xff,0xb2,0xd,0x89,0x62,
  0x29,0xc2,0x18,0xbe,0xc7,0x4b,0x8e,0x5c,0xad,0xdc,0x28,0x1,0x2c,0x14,0xee,0x85,
  0xe2,0x67,0xc8,0x24,0x63,0x38,0x8c,0xd3,0x18,0x89,0xe4,0xd9,0x6c,0xf9,0x53,0x86,
  0xef,0xc2,0x28,0x66,0xc6,0x70,0xbe,0x87,0x56,0x64,0xce,0x96,0xb1,0x3,0xdf,0x6f,
  0xdf,0x9c,0x3b,0x6f,0x87,0xd,0x8d,0xd3,0x5b,0x9c,0xee,0xcd,0xd7,0xa7,0x75,0x6d,
  0x5a,0x17,0xd1,0xd8,0x36,0x56,0xe8,0x9b,0x69,0xbb,0xd9,0x4c,0xd5,0xaa,0x89,0xa9,
  0xc6,0xd5,0x6a,0xdc,0xce,0xa8,0xe3,0x2b,0xdf,0x34,0x90,0xfb,0x26,0xa6,0x6,0x94,
  0xdc,0x54,0x83,0x42,0x9d,0xda,0x7c,0xb5,0xf5,0x9b,0x6e,0xda,0xb6,0x79,0x18,0xe7,
  0x1b,0x5d,0x1,0x80,0xf,0x0,0x32,0x14,0xa,0xb2,0xff,0xad,0x29,0x8a,0xfd,0xd4,
  0x92,0xb0,0x97,0xfd,0x80,0x9d,0xa7,0x97,0xbb,0x26,0xfb,0x51,0xc9,0x7f,0x71,0xc4,
  0xb1,0x1d,0xe3,0x6,0xce,0x69,0x63,0xe7,0x56,0xd3,0x36,0xe7,0x36,0x7d,0x2d,0xbe,
  0x88,0x80,0x40,0x28,0x9a,0xbe,0xe6,0x7b,0x35,0x5f,0x4a,0xad,0xf5,0xaa,0x57,0xd7,
  0xae,0x1b,0x37,0x6e,0x84,0x10,0x6,0x80,0xb7,0xa8,0xe1,0x21,0x63,0x37,0x93,0x82,
  0x24,0xcb,0x1c,0x30,0x84,0x10,0x32,0x72,0xd0,0xa6,0x3,0x52,0x50,0x28,0x46,0x31,
  0x4,0x8,0x49,0x10,0x11,0x20,0x8,0x46,0x80,0x90,0x8,0x82,0x20,0x4,0xc,0x41,
  0x83,0x10,0xa1,0x11,0x18,0x24,0x20,0x2,0x22,0x40,0xd4,0xf,0x33,0xb7,0x5d,0x14,
  0xf9,0x92,0x14,0xb3,0xd,0x5e,0x4c,0xda,0xb9,0x6a,0x4a,0x62,0x52,0x43,0xd,0xb6,
  0xc5,0xbf,0xec,0x99,0x43,0x2d,0x4,0x45,0x3,0x44,0x2c,0x6,0x77,0x62,0x10,0x3a,
  0x39,0x1,0x9,0x2d,0xb2,0xa,0x19,0x3c,0xe4,0xa5,0xc6,0x44,0x80,0xeb,0xe3,0x4d,
  0x16,0xc1,0x15,0x97,0xd4,0x31,0x60,0x4a,0xaa,0x8,0xa6,0xa1,0xe0,0x6b,0x46,0xa,
  0xb7,0xc9,0x0,0x49,0x22,0x61,0xa5,0xf,0x48,0xbe,0x6,0x54,0xd8,0x68,0x31,0x85,
  0x1d,0x3b,0xeb,0xcb,0x6c,0xa1,0x5,0x71,0xa2,0x7,0x83,0x0,0x99,0x2e,0x0,0x49,
  0x2,0x40,0xe2,0x14,0xc6,0x8,0x69,0xe1,0x73,0xa0,0x42,0x49,0xe0,0xe8,0x15,0x7e,
  0x9b,0x5d,0xcd,0x70,0xe8,0x1c,0xad,0x88,0xf7,0xe2,0xce,0x39,0x33,0x2,0x2b,0x90,
  0x65,0x6c,0x11,0xe3,0xd9,0xab,0x9,0xab,0x7f,0x3d,0x18,0x82,0x84,0x89,0x15,0x3d,
  0xc1,0x64,0x61,0x9c,0x1c,0x92,0x91,0x36,0x4c,0x0,0x6c,0x69,0x25,0x62,0xe3,0x4f,
  0xdc,0xe7,0x3b,0x90,0x15,0x72,0x33,0x2c,0xe4,0xe8,0x96,0x83,0x14,0x1c,0x99,0xfe,
  0x26,0xaa,0x6b,0x29,0x3a,0x21,0x6,0xd0,0x2b,0xcc,0xfd,0x25,0x0,0xa2,0xa5,0x53,
  0x89,0x30,0x2,0x1,0xec,0x95,0xe8,0x3f,0x89,0xe8,0xca,0x57,0xa5,0x6f,0x18,0xaa,
  0x70,0x47,0xb,0xe2,0x3f,0x47,0x1d,0x50,0x43,0xd1,0xa0,0x2b,0x6d,0x21,0xb4,0x90,
  0xa4,0x83,0xd1,0xa1,0xe,0x41,0x7,0x19,0xd1,0x81,0x55,0xc8,0xfd,0x41,0x7e,0x22,
  0x84,0x89,0x43,0xb0,0x70,0x97,0xfe,0x40,0x46,0x84,0x94,0x35,0x2c,0xb6,0x87,0x56,
  0x2b,0x80,0xd9,0x74,0x52,0xbb,0xf9,0xf8,0x31,0x86,0x66,0xf6,0xa2,0x1,0x66,0x22,
  0xbd,0x14,0x44,0x25,0xee,0x4,0x61,0x0,0x33,0x53,0x47,0x16,0xed,0xa5,0xc1,0x3a,
  0x5a,0x46,0xc,0xf4,0x8c,0x70,0x97,0xf,0xd1,0x7,0xc9,0x4b,0x96,0xbd,0x4b,0x98,
  0xa0,0x19,0x84,0xcb,0xa7,0x87,0xdf,0x3,0x93,0x2b,0x8a,0xa1,0x1f,0xf0,0x1,0x4,
  0x5,0x70,0xad,0xde,0x5d,0x5b,0x92,0x96,0x0,0x2d,0x91,0xf1,0xfb,0xd1,0x86,0xac,
  0x24,0xd9,0x97,0xc4,0xf9,0x15,0xff,0x85,0xa8,0x32,0xb6,0xc0,0x3b,0x9e,0xb0,0xce,
  0x71,0x8a,0xaa,0xd8,0x2b,0xe3,0x14,0x78,0xf4,0x94,0x1a,0xa2,0x48,0x26,0x13,0xf8,
  0xd8,0x44,0x48,0x8c,0xce,0x59,0xc6,0x63,0x17,0x7e,0xde,0x16,0xef,0x7e,0x55,0xd6,
  0x4,0x60,0xf1,0xf8,0x24,0x6e,0x47,0x2d,0xa0,0x1a,0x3c,0xf,0x75,0x93,0x2a,0x5e,
  0xdf,0xa3,0x1d,0x1e,0x1b,0xcb,0xdc,0x1b,0xe1,0x4f,0x48,0x71,0x88,0x22,0xd3,0x42,
  0xb3,0xc7,0x56,0xb0,0x70,0xdc,0x17,0xab,0x13,0x93,0xf,0xef,0x45,0xe7,0xf8,0x33,
  0x42,0x3e,0x4,0x85,0xe,0x90,0xf7,0x4c,0xed,0xc2,0x4f,0xef,0x18,
  
};

static const unsigned char qt_resource_name[] = {
  // assets
  0x0,0x6,
  0x6,0x8a,0x9c,0xb3,
  0x0,0x61,
  0x0,0x73,0x0,0x73,0x0,0x65,0x0,0x74,0x0,0x73,
    // data
  0x0,0x4,
  0x0,0x6,0xa8,0xa1,
  0x0,0x64,
  0x0,0x61,0x0,0x74,0x0,0x61,
    // deepin-compressor.json
  0x0,0x16,
  0x2,0x95,0x4c,0xbe,
  0x0,0x64,
  0x0,0x65,0x0,0x65,0x0,0x70,0x0,0x69,0x0,0x6e,0x0,0x2d,0x0,0x63,0x0,0x6f,0x0,0x6d,0x0,0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,0x73,0x0,0x6f,0x0,0x72,
  0x0,0x2e,0x0,0x6a,0x0,0x73,0x0,0x6f,0x0,0x6e,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x9a,0x1d,0x34,0x15,0x80,
  // :/assets
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x9a,0x1d,0x34,0x15,0x80,
  // :/assets/data
  0x0,0x0,0x0,0x12,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x1,0x9a,0x1d,0x34,0x15,0x80,
  // :/assets/data/deepin-compressor.json
  0x0,0x0,0x0,0x20,0x0,0x4,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x9a,0x1d,0x34,0x15,0x80,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#if defined(QT_INLINE_NAMESPACE)
inline namespace QT_NAMESPACE {
#elif defined(QT_NAMESPACE)
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#if defined(__ELF__) || defined(__APPLE__)
static inline unsigned char qResourceFeatureZstd()
{
    extern const unsigned char qt_resourceFeatureZstd;
    return qt_resourceFeatureZstd;
}
#else
unsigned char qResourceFeatureZstd();
#endif

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_config)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_config)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_config)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_config)()
{
    int version = 3;
    version += QT_RCC_PREPEND_NAMESPACE(qResourceFeatureZstd());
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

#ifdef __clang__
#   pragma clang diagnostic push
#   pragma clang diagnostic ignored "-Wexit-time-destructors"
#endif

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_config)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_config)(); }
   } dummy;
}

#ifdef __clang__
#   pragma clang diagnostic pop
#endif
